struct SlotGuard;Expand description
Guard that acquires a slot on construction and calls releases slot on drop, even if the task panics or returns early.
Implementations
Sourceimpl SlotGuard
impl SlotGuard
Sourcepub fn try_acquire_slot() -> Result<Self, SpawnError>
pub fn try_acquire_slot() -> Result<Self, SpawnError>
Attempts to acquire a slot for a new task.
Returns Ok(()) if no limit or slot acquired, Err(QueueFull) if at limit.